Class: NumPlot::EnhancedText
- Inherits:
-
Object
- Object
- NumPlot::EnhancedText
- Defined in:
- lib/numplot.rb
Overview
Represents “enhanced text” in enhanced text mode All unmarked texts are handled as “non enhanced text” and all special characters are escaped in enhanced text mode.
Instance Attribute Summary collapse
-
#text ⇒ String
readonly
A text.
Instance Method Summary collapse
-
#initialize(text) ⇒ EnhancedText
constructor
Create an EnhancedText object.
Constructor Details
#initialize(text) ⇒ EnhancedText
Create an EnhancedText object.
You can use the short-cut method NumPlot#ET.
756 757 758 |
# File 'lib/numplot.rb', line 756 def initialize(text) @text = text end |
Instance Attribute Details
#text ⇒ String (readonly)
Returns a text.
761 762 763 |
# File 'lib/numplot.rb', line 761 def text @text end |